@@ -61,6 +61,11 @@ gib_hash *gib_hash_new()
 
 void      gib_hash_free(gib_hash *hash)
 {
+	/* free hash keys as it's not taken care of by gib_list_free */
+	gib_list *i;
+	for (i = GIB_LIST(hash->base); i; i = i->next)
+		gib_efree(GIB_HASH_NODE(i)->key);
+
 	gib_list_free(GIB_LIST(hash->base));
 	gib_efree(hash);
 	return;
@@ -68,6 +73,11 @@ void      gib_hash_free(gib_hash *hash)
 
 void      gib_hash_free_and_data(gib_hash *hash)
 {
+	/* free hash keys as it's not taken care of by gib_list_free */
+	gib_list *i;
+	for (i = GIB_LIST(hash->base); i; i = i->next)
+		gib_efree(GIB_HASH_NODE(i)->key);
+
 	gib_list_free_and_data(GIB_LIST(hash->base));
 	gib_efree(hash);
 	return;
@@ -77,12 +87,14 @@ static unsigned char gib_hash_find_callback(gib_list *list, void *data)
 {
 	gib_hash_node *node = GIB_HASH_NODE(list);
 	char          *key  = (char*) data;
-		
-	return !strncasecmp(node->key, key,strlen(node->key));
+
+	/* strncasecmp causes simliar keys like key1 and key11 clobber eachother */
+	return !strcasecmp(node->key, key);
 }
 
 void      gib_hash_set(gib_hash *hash, char *key, void *data)
 {
+	gib_list *l;
 	gib_hash_node *n;
 
 	n = GIB_HASH_NODE(gib_list_find(GIB_LIST(hash->base),
@@ -91,10 +103,17 @@ void      gib_hash_set(gib_hash *hash, char *key, void *data)
 	if (n)	{
 		GIB_LIST(n)->data = data;
 	} else {
+		/* not using gib_list_add_end here as that would nest the
+			 data one level, doing manual insert instead */
 		n = gib_hash_node_new(key,data);
-		gib_list_add_end(GIB_LIST(hash->base),n);
+		l = gib_list_last(GIB_LIST(hash->base));
+
+		GIB_LIST(n)->next = NULL;
+		GIB_LIST(n)->prev = l;
+
+		if (l)
+			l->next = GIB_LIST(n);
 	}
-	return;
 }
 
 void     *gib_hash_get(gib_hash *hash, char *key)
@@ -106,8 +125,11 @@ void     *gib_hash_get(gib_hash *hash, char *key)
 void      gib_hash_remove(gib_hash *hash, char *key)
 {
 	gib_list *n = gib_list_find(GIB_LIST(hash->base), gib_hash_find_callback, key);
-	if (n)
+	if (n) {
 		gib_list_unlink(GIB_LIST(hash->base), n);
+    gib_hash_node_free(GIB_HASH_NODE(n->data));
+  }
+
 	return;
 }
 
